-- LSCM Unwrap SEAM Edges
-- by Christoph 'CrazyButcher' Kubisch
-- http://crazybutcher.luxinia.de
-- version 1.0
--
--
-- to be used with the accompanying LSCMunwrap_xxxx.gup and CB_LSCMUnwrapFuncs.ms
-- based on
-- Bruno Levy, Sylvain Petitjean, Nicolas Ray, Jerome Maillot. Least Squares
-- Conformal Maps for Automatic Texture Atlas Generation. In Siggraph 2002,
-- July 2002.

macroScript LSCMUnwrapMain
category:"CrazyButcher"
buttonText:"LSCM Central"
tooltip:"LSCM Central"
(
	
	local rollUnwrap
	local rollOptions
	local rollHelp
	local rollAbout
	
	local lscm_pos [10,20]
	global lscm_rollFloater
	
	rollout rollUnwrap "LSCM Unwrap"(
		
		group "Seam Edges"(
			button btn_markedge "Mark" width:50 across:3 
			button btn_unmarkedge "Unmark" width:50 
			button btn_seledge "Select" width:50
		)

		checkbox cb_draw "Display Seams" checked:lscmdrawstate align:#center offset:[0,4]
		
		spinner sp_map "Map Channel:" range:[1,99,LSCMUnwrap.getchannel()] fieldwidth:40 type:#integer align:#center offset:[0,6]
		--checkbox cb_mod "Add new modifier" checked:true align:#center
		button btn_unwrap "LSCM Unwrap" align:#center width:140
		
		group "Based on top Unwrap Modifier"(
			checkbox cb_faces "Only selected Faces" checked:(LSCMUnwrap.getonlyselected()) align:#center 
			checkbox cb_verts "Lock selected Vertices  " checked:(LSCMUnwrap.getpinvertices()) align:#center 
		)
		
		on btn_markedge pressed do (
			if (not (classOf selection[1] == PolyMeshObject or classof selection[1] == Editable_Poly )) then
				messagebox "Requires 1 PolyMeshObject/Editable_Poly "	
			else
				LSCM_markedge()
		)
		on btn_unmarkedge pressed do (
			if (not (classOf selection[1] == PolyMeshObject or classof selection[1] == Editable_Poly )) then
				messagebox "Requires 1 PolyMeshObject/Editable_Poly "
			else	
				LSCM_unmarkedge()
		)
		on btn_seledge pressed do (
			if (not (classOf selection[1] == PolyMeshObject or classof selection[1] == Editable_Poly )) then
				messagebox "Requires 1 PolyMeshObject/Editable_Poly "
			else
				LSCM_selectEdges()
		)
		on cb_draw changed state do(
			LSCM_drawToggle()
			cb_draw.state = lscmdrawstate
		)
		on cb_faces changed state do(
			LSCMUnwrap.setonlyselected state
		)
		on cb_verts changed state do(
			LSCMUnwrap.setpinvertices state
		)
		on sp_map changed value do(
			LSCMUnwrap.setchannel value
		)
		
		on btn_unwrap pressed do (
			local sel = selection as array
			if (sel.count == 1 and (classOf sel[1] == PolyMeshObject or classof sel[1] == Editable_Poly )) then (
				print "Starting LSCM Unwrap"

				LSCMUnwrap.unwrap sel[1]
				print "Finished LSCM Unwrap"
			)
			else (
				messagebox "Requires 1 PolyMeshObject/Editable_Poly "	
			)
		)
	)
	
	rollout rollOptions "Options" rolledup:true(
		group "General"(
		spinner sp_weld "Weld threshold (/1000):" range:[0,1000,LSCMUnwrap.getweldthreshold()*1000] scale:0.001 fieldwidth:50 type:#float align:#left 
		spinner sp_bit "EdgeFlag bit:" range:[25,32,LSCMUnwrap.getedgeflagbit()] fieldwidth:30 type:#integer align:#left
		spinner sp_packmax "pack max width:" range:[0,2,LSCMUnwrap.getpackmax()] scale:0.01 fieldwidth:50 type:#float align:#left 
		)
		group "Draw Seams"(
		colorpicker cp_seamcolor "Color:" align:#left color:(LSCMUnwrap.getseamcolor()) fieldwidth:30 height:14 across:2
		checkbox cb_zbuffer "Z-Buffer" height:14 checked:(LSCMUnwrap.getdrawzbuffered())
		)
		button btn_save "Save Options" align:#center
		
		on cp_seamcolor changed new_col do(
			LSCMUnwrap.setseamcolor new_col
		)
		on cb_zbuffer changed state do(
			LSCMUnwrap.setdrawzbuffered state
		)
		on sp_bit changed bitid do(
			LSCMUnwrap.setedgeflagbit bitid
		)
		on sp_weld changed value do(
			LSCMUnwrap.setweldthreshold (value/1000)
			sp_weld.value = value	
		)
		on sp_packmax changed value do (
			LSCMUnwrap.setpackmax value
			sp_packmax.value = value
		)
		on btn_save pressed do(
			setinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "weldthresh" (rollOptions.sp_weld.value as string)
			setinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "packmax" (rollOptions.sp_packmax.value as string)
			setinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "edgebit" (rollOptions.sp_bit.value as string)
			setinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "seamcolor" (rollOptions.cp_seamcolor.color as string)
			setinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "seamzbuffer" (rollOptions.cb_zbuffer.checked as string)
		)
	)
	
	
	rollout rollHelp "Help" rolledup:true(
		group "General"(
		label hp01 "Only operates on EditablePoly." align:#left
		label hp02 "If distortions occur, lowering the" align:#left
		label hp03 "weld threshold might help." align:#left
		label hp04 "The Threshold is divided by 1000," align:#left
		label hp05 "so 100 => 0.1 (Spinners dont allow" align:#left
		label hp06 "greater precision behind the comma)" align:#left
		label hp07 "The packmax value means the width" align:#left
		label hp08 "of the biggest chunk in uv space" align:#left
		)
		
		group "Display Seams" (
		label hp1 "Only the first node in your selection" align:#left
		label hp2 "will be drawn with seams." align:#left
		label hp22 "Only when edge selections or edgecount" align:#left
		label hp23 "changed the seams will be updated" align:#left
		label hp21 "The button state sometimes may be"  align:#left
		label hp3 "wrong, but when clicked on, it will" align:#left
		label hp4 "be corrected." align:#left
		)
	)
	
	rollout rollAbout "About" rolledup:true(
	
		label ab0 "LSCMUnwrapper v1.0"
		label ab1 "----------------------------------"
		label ab2 "ported by Christoph Kubisch"
		hyperlink ab3 "crazybutcher.luxinia.de" address:"http://crazybutcher.luxinia.de" align:#center
		label ab31 ""
		label ab4 "unwrap code from blender3d"
		label ab5 "by Brecht Van Lommel"
		label ab51 "and Jens Ole Wund"
		hyperlink ab6 "www.blender3d.org" address:"http://www.blender3d.org" align:#center
		label ab62 ""
		label ab7 "uses OpenNL by Bruno Levy"
		hyperlink ab8 "www.loria.fr/~levy" address:"http://www.loria.fr/~levy" align:#center
		label ab81 ""
		label t00 "No guarantees. Plugin might" 
		label t01 "crash, atomize your pc..." 
		label t02 "Use at your own risk !" 
		label t03 "On problems email me" offset:[0,5]
		hyperlink t04 "crazybutcher@gmx.de" address:"mailto:crazybutcher@gmx.de" align:#center

	)
		
	if (lscm_rollFloater == undefined or not lscm_rollFloater.open) then 
	(
	
		lscm_rollFloater= newRolloutFloater "LSCMUnwrapper" 220 300 
		addRollout rollUnwrap lscm_rollFloater
		addRollout rollOptions lscm_rollFloater
		addRollout rollHelp lscm_rollFloater
		addRollout rollAbout lscm_rollFloater
		
		if ((getfiles (getdir #plugcfg + "\\cb_lscm.ini")).count != 0) then
		(
			rollOptions.sp_bit.value = (getinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "edgebit") as integer
			rollOptions.sp_packmax.value = (getinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "packmax") as float
			if (rollOptions.sp_packmax.value == 0) then (
				rollOptions.sp_packmax.value = 0.5
			)
			rollOptions.sp_weld.value = (getinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "weldthresh") as float
			if (rollOptions.sp_weld.value == 0) then (
				rollOptions.sp_weld.value = 0.01
			)
			rollOptions.cp_seamcolor.color = readvalue ((getinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "seamcolor") as stringstream)
			rollOptions.cb_zbuffer.checked = readvalue ((getinisetting (getdir #plugcfg + "\\cb_lscm.ini") "settings" "seamzbuffer") as stringstream)
		
			LSCMUnwrap.setseamcolor rollOptions.cp_seamcolor.color
			LSCMUnwrap.setedgeflagbit rollOptions.sp_bit.value
			LSCMUNwrap.setdrawzbuffered rollOptions.cb_zbuffer.checked
			LSCMUnwrap.setpackmax rollOptions.sp_packmax.value
			LSCMUnwrap.setweldthreshold (rollOptions.sp_weld.value/1000)
		)
	)
	
)

		
macroScript LSCMUnwrapDo
category:"CrazyButcher" 
buttonText:"LSCM Unwrap"
tooltip:"LSCM Unwrap (Poly)" 
(
	On IsEnabled Return Filters.Is_EditPoly()
	On IsVisible Return Filters.Is_EditPoly()

	On Execute Do (
		local sel = selection as array
		if (sel.count == 1 and (classOf sel[1] == PolyMeshObject or classof sel[1] == Editable_Poly )) then (
			print "Starting LSCM Unwrap"

			LSCMUnwrap.unwrap sel[1]
			print "Finished LSCM Unwrap"
		)
		else (
			messagebox "Requires 1 PolyMeshObject/Editable_Poly "	
		)
	)
)

macroScript LSCMUnwrapMarkEdge
category:"CrazyButcher" 
buttonText:"LSCM Mark Seam"
tooltip:"LSCM Mark Seam (Poly)" 
(
	On IsEnabled Return Filters.Is_EditPoly()
	On IsVisible Return Filters.Is_EditPoly()

	On Execute Do (
		LSCM_markEdge()
	)
)

macroScript LSCMUnwrapUnMarkEdge
category:"CrazyButcher" 
buttonText:"LSCM Unmark Seam"
tooltip:"LSCM Unmark Seam (Poly)" 
(
	On IsEnabled Return Filters.Is_EditPoly()
	On IsVisible Return Filters.Is_EditPoly()

	On Execute Do (
		LSCM_unmarkEdge()
	)
)

macroScript LSCMUnwrapSelectEdge
category:"CrazyButcher" 
buttonText:"LSCM Select Seam"
tooltip:"LSCM Get Seam Edges (Poly)" 
(
	On IsEnabled Return Filters.Is_EditPoly()
	On IsVisible Return Filters.Is_EditPoly()

	On Execute Do (
		LSCM_selectEdges()
	)
)

macroScript LSCMUnwrapDrawSeams
category:"CrazyButcher" 
buttonText:"LSCM Display Seams"
tooltip:"LSCM Display Seam Edges (Toggle)" 
(
	local drawactive = false 
	
	On IsEnabled Return Filters.Is_EditPoly()
	On IsVisible Return Filters.Is_EditPoly()
	
	
	On Execute Do (
		LSCM_drawtoggle()
	)
)